/* 
 * Copyright (c) 2013 Amr Hassan <amr.hassan@gmail.com>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining 
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal in the Software without restriction, including 
 * without limitation the rights to use, copy, modify, merge, publish, 
 * distribute, sublicense, and/or sell copies of the Software, and to 
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be 
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package net.amrhassan.sqlbuilder.restrictions;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import net.amrhassan.sqlbuilder.utils.StringUtils;

class AndSqlRestriction implements SqlRestriction {
	
	private Collection<SqlRestriction> operands;
	
	AndSqlRestriction(Collection<SqlRestriction> operands) {
		this.operands = operands;
	}
	
	@Override
	public String toString() {
		
		List<String> operandStrings = new LinkedList<String>();
		
		String restrictionFormat = "(%s)";
		if (operands.size() < 2)
			restrictionFormat = "%s";
		
		for (SqlRestriction operand : operands) {
			operandStrings.add(String.format(restrictionFormat, 
					operand.toString()));
		}
		
		return StringUtils.join(" AND ", operandStrings);
	}
}
